@@ -10,8 +10,6 @@ OC.L10N.register(
     "Cheers!" : "ไชโย!",
     "Calendar" : "ปฏิทิน",
     "Confirm" : "ยืนยัน",
-    "Anniversary" : "วันครบรอบ",
-    "Personal" : "ส่วนตัว",
     "Today" : "วันนี้",
     "Day" : "วัน",
     "Week" : "สัปดาห์",
@@ -49,6 +47,7 @@ OC.L10N.register(
     "Sunday" : "วันอาทิตย์",
     "Update" : "อัปเดต",
     "Your email address" : "ที่อยู่อีเมลของคุณ",
+    "Notification" : "การแจ้งเตือน",
     "Email" : "อีเมล",
     "Delete file" : "ลบไฟล์",
     "Choose a file to add as attachment" : "เลือกไฟล์ที่ต้องการแนบ",
@@ -57,6 +56,7 @@ OC.L10N.register(
     "Decline" : "ปฏิเสธ",
     "Tentative" : "ชั่วคราว",
     "Send email" : "ส่งอีเมล",
+    "Remove group" : "ลบกลุ่ม",
     "Repeat" : "ทำซ้ำ",
     "never" : "ไม่ต้องเลย",
     "after" : "หลังจาก",
@@ -64,9 +64,12 @@ OC.L10N.register(
     "Pick a date" : "เลือกวันที่",
     "Global" : "ทั่วไป",
     "Subscribe" : "สมัครรับข้อมูล",
+    "Personal" : "ส่วนตัว",
     "Details" : "รายละเอียด",
     "Attendees" : "ผู้เข้าร่วมกิจกรรม",
+    "Resources" : "ทรัพยากร",
     "Close" : "ปิด",
+    "Anniversary" : "วันครบรอบ",
     "Week {number} of {year}" : "สัปดาห์ที่ {number} ของปี {year}",
     "Daily" : "รายวัน",
     "Weekly" : "รายสัปดาห์",
