@@ -69,8 +69,8 @@ class AvailabilityGenerator {
 		//      when the user opens the page at 10:17.
 		// But only do this when the time isn't already a "pretty" time
 		if ($earliestStart % $config->getIncrement() !== 0) {
-			$roundTo = (int)round(($config->getIncrement()) / 300) * 300;
-			$earliestStart = (int)ceil($earliestStart / $roundTo) * $roundTo;
+			$roundTo = (int)(round(($config->getIncrement()) / 300) * 300);
+			$earliestStart = (int)(ceil($earliestStart / $roundTo) * $roundTo);
 		}
 
 		$latestEnd = min(
